<?php
/******************************************************************************
 * File:				pdf.php
 * Author:				Thorsten Rinne          <thorsten@rinne.info>
 * Contributor:         Krzysztof Kruszynski    <thywolf@wolf.homelinux.net>
 *
 * Portions of this Code is copyrighted by
 *						Olivier Plathey		olivier@fpdf.org
 *
 * Date:				2003-02-12
 * Last change:			2003-10-29
 * Copyright:           (c) 2001-2003 Thorsten Rinne und Bastian Pttner
 * 
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 ******************************************************************************/

/* FPDF und alles andere einbinden */
define("FPDF_FONTPATH", "./font/");
require_once ("inc/functions.php");
require_once ("inc/config.php");
require_once ("inc/data.php");
require_once ("inc/database.php");

//if (isset($_REQUEST["lang"]) && $_REQUEST["lang"] == "zh") {
//    require_once ("inc/chinese.php");
//    }
//else {
    require_once ("inc/fpdf.php");
//    }

$db = new db_mysql();
$db->connect($mysql_server, $mysql_user, $mysql_passwort, $mysql_db);

$categories = getCategories();

/* Sprache auswhlen */
if (strlen($sprache) < 1 || !is_file("lang/".$sprache)) {
	include "lang/english.php";
	print "No langauge file found";
	die();
	}
else {
	include "lang/".$sprache;
	}

class PDF extends FPDF {
	var $B;
	var $I;
	var $U;
	var $SRC;
	var $HREF;
	var $PRE;
	var $CENTER;
	
	// PDF-Header
	function Header() {
		global $rubrik, $thema, $categories;
		$title = stripslashes($categories[$rubrik]).": ".stripslashes($thema);
		$this->SetFont("Arial", "B", 16);
		$this->SetDrawColor(182,195,203);
		$this->SetFillColor(239,239,239);
		$this->SetTextColor(0,0,0);
		$this->SetLineWidth(1);
		$this->MultiCell(0, 9, $title, 1, 1, "C", 1);
		$this->Ln(8);
		}
	
	// PDF-Footer
	function Footer() {
		global $ad_gen_page, $metaPublisher, $adminmail, $rubrik;
    	$this->SetY(-25);
    	$this->SetFont("Arial", "I", 10);
    	$this->Cell(0, 10, $ad_gen_page." ".$this->PageNo()."/{nb}",0,0,"C");
		$this->SetY(-20);
    	$this->SetFont("Arial", "B", 8);
		$this->Cell(0, 10, "(c) ".date("Y")." ".$metaPublisher." <".$adminmail.">",0,1,"C");
		$this->SetY(-15);
    	$this->SetFont("Arial", "", 8);
		$this->Cell(0, 10, "URL: http://".$_SERVER["HTTP_HOST"].str_replace("pdf.php", "index.php?aktion=artikel&rubrik=".$rubrik."&id=".$_REQUEST["id"]."&lang=".$_REQUEST["lang"], $_SERVER["PHP_SELF"]),0,1,"C");
		}
	
	// PDF Konstruktor
	function PDF ($orientation = "P", $unit = "mm", $format = "A4") {
		$this->FPDF($orientation, $unit, $format);
		$this->B = 0;
		$this->I = 0;
		$this->U = 0;
		$this->PRE = 0;
		$this->CENTER = 0;
		$this->SRC = "";
		$this->HREF = "";
		}
	
	// HTML-Parser
	function WriteHTML($html) {
		$html = str_replace("\n", "<br>", $html);
    	$a = preg_split("/<(.*)>/U", $html, -1, PREG_SPLIT_DELIM_CAPTURE);
		foreach($a as $i => $e) {
			if ($i % 2 == 0) {
				if ($this->HREF) {
					$this->PutLink($this->HREF,$e);
					}
				elseif ($this->SRC) {
					$this->AddImage($this->SRC);
                    $this->SRC = "";
					}
				elseif ($this->CENTER) {
					$this->MultiCell(0, 1, $e, 0, "C");
					}
            	else {
                	$this->Write(5,$e);
					}
        		}
        	else {
				if ($e{0} == "/") {
					$this->CloseTag(strtoupper(substr($e,1)));
					}
				else {
					$a2 = explode(" ",$e);
					$tag = strtoupper(array_shift($a2));
					$attr = array();
					foreach ($a2 as $v) {
						if (ereg('^([^=]*)=["\']?([^"\']*)["\']?$',$v,$a3)) {
                        	$attr[strtoupper($a3[1])]=$a3[2];
							}
						}
                	$this->OpenTag($tag,$attr);
            		}
        		}
    		}
		}
	
	function OpenTag($tag, $attr) {
		
		if ($tag == "B" or $tag == "I" or $tag == "U") {
			$this->SetStyle($tag,true);
			}
		if ($tag == "PRE") {
			$this->SetFont("Times", "", 11);
			}
		if ($tag == "A") {
			$this->HREF = $attr["HREF"];
			}
		if ($tag == "IMG") {
			$this->SRC = $attr["SRC"];
			}
		if ($tag == "DIV") {
            if ($attr["ALIGN"] != "justify") {
                $this->CENTER = $attr["ALIGN"];
                }
			}
         if ($tag == "UL") {
            $this->SetLeftMargin($this->lMargin+10);
            }
         if ($tag == "LI") {
            $this->Ln();
            $this->SetX($this->GetX()-10);
            $this->Cell(10,5,chr(149),0,0,'C');
            }
		if ($tag == "BR") {
			$this->Ln(5);
			}
		}
	
	function CloseTag($tag) {
		
		if ($tag == "B" or $tag == "I" or $tag == "U") {
			$this->SetStyle($tag,false);
			}
		if ($tag == "PRE") {
			$this->SetFont("Arial", "", 12);
			}
		if ($tag == "A") {
			$this->HREF = "";
			}
		if ($tag == "DIV") {
			$this->CENTER = "";
			}
         if ($tag == "UL") {
            $this->SetLeftMargin($this->lMargin-10);
            $this->Ln();
            }
		}
	
	function SetStyle($tag,$enable) {
		
		$this->$tag += ($enable ? 1 : -1);
		$style = "";
		foreach (array("B", "I", "U") as $s) {
			if ($this->$s > 0) {
				$style .= $s;
				}
			}
		$this->SetFont("", $style);
		}
	
	function PutLink($URL, $txt) {
		$this->SetTextColor(0, 0, 255);
		$this->SetStyle("U", true);
		$this->Write(5, $txt, $URL);
		$this->SetStyle("U", false);
		$this->SetTextColor(0);
		}
	
	function AddImage($image) {
		$info = GetImageSize($image);
        $w = $info[0] / 150 * 25.4;
        $h = $info[1] / 150 * 25.4;
        $hw_ratio = $h / $w;
		$this->Ln();
		if ($info[0] > $this->wPt) {
			$info[0] = $this->wPt - $this->lMargin - $this->rMargin;
            if ($w > $this->w) {
                $w = $this->w - $this->lMargin - $this->rMargin;
                $h = $w*$hw_ratio;
                }
			}
		$x = $this->GetX();
		$this->SetX(($this->wPt - $info[0]) / 2);
        $this->SetX(($this->w - $w) / 2);
        $x = $this->GetX();
		if ($this->GetY() + $h > $this->h) {
			$this->AddPage();
			}
		$y = $this->GetY();
        $this->Image($image, $x, $y, $w, $h);
        if ($y + $h > $this->hPt) {
            $this->AddPage();
            }
        else {
            $this->SetY($y+$h);
            }
		}
	}

// Variablenprfung
if (isset($_REQUEST["id"]) && checkIntVar($_REQUEST["id"]) == TRUE) {
	$id = $_REQUEST["id"];
	}

$result = $db->query("SELECT id, lang, rubrik, thema, content, datum, author FROM ".$sqltblpre."faqdata WHERE id = '".$id."' AND lang = '".$_REQUEST["lang"]."' AND active = 'yes'");
if ($db->num_rows($result) > 0) {
	while ($row = $db->fetch_object($result)) {
		$lang = $row->lang;
		$rubrik = $row->rubrik;
		$thema = $row->thema;
		$content = $row->content;
		$date = $row->datum;
		$author = $row->author;
		}
	}
else {
	print "Error!";
	}

//if ($lang == "zh") {
//    $pdf = new PDF_Chinese();
//    }
//else {
    $pdf = new PDF();
//    }
$pdf->Open();
$pdf->AliasNbPages();
$pdf->AddPage();
$pdf->SetFont("Arial", "", 12);

if ($ubbcode == "true") {
	$pdf->WriteHTML(unhtmlentities(parseUBB($content)));
	}
else {
	$pdf->WriteHTML(unhtmlentities(stripslashes($content)));
	}

$pdfFile = "pdf/".$id.".pdf";
$pdf->Output($pdfFile);

header("Location: ".$pdfFile."");
?>